// Sviluppato da Mauro Donati
// Modified by Jason O. Jensen and Eric Jensen

/*  This file contains the power information that will be analysed by the search engine. In case of changes to the
power list in the site, it should be kept up-to-date in order to obtain correct information by the search engine.

The structure is an array of arrays of strings, each of the inner arrays contains data related to one power.

var spelllist = new Array(
    new Array('Power 1 name',       'Discipline',     'Subdiscipline', 'Descriptor',
              'Class and Levels', 'Display', 'Link',      'Short description'),
    new Array('Power 2 name',       'Discipline',     'Subdiscipline', 'Descriptor',
              'Class and Levels', 'Display', 'Link',      'Short description'),
    ...
    new Array('Power 98 name',       'Discipline',     'Subdiscipline', 'Descriptor',
              'Class and Levels', 'Display', 'Link',      'Short description'),
    new Array('Power 99 name',       'Discipline',     'Subdiscipline', 'Descriptor',
              'Class and Levels', 'Display', 'Link',      'Short description'),
);


The search engine will load the main array, check the search criteria row by row and print the spell if its row
matches every selected criterion; thus, it is important for the inner arrays to be alpha-sorted on the spell name
to obtain an alpha-sorted spell list.

Each of the inner arrays is composed by eigth string fields:
- Power name (must be in alphabetical order)
- Discipline: should correspond to the value of one option in the discipline select of the search page.
- Sub-discipline: should correspond to the value of one option in the sub-discipline select of the search page or be void.
- Descriptor list: should be a ', ' (comma and space) separated list of fields, each of them should correspond to
          the value of one option in the descriptor select of the search page. May be void
- Class/Level: should be a ', ' separated list of fields composed by a *word*, a ' ' (space) and a *number*.
          the *word* should correspond to the value of one option in the class select of the main page, the
          *number* - the level - should span from 1 to 9. At least a couple word-number is expected to be present.
- Display: should be a ', ' separated list of fields, each of them should correspond to the value of one option
          in the component select of the search page. At least one is expected to be present.
- Link: should be a valid link to the page containing the description of the spell, such as: 'spellsAtoB.html#name'
- Short Description: Short description of the spell like the one in the class spell lists.

Not too clear? Maybe the best examples are in the table itself!

Search is case-insensitive, but capital letters should be used in the right way to obtain a correct display.

*** please remember to escape the ' (single quotes) with '\' (backslash) in any fields (as in 'Bear\' Endurance'),
or it will lead to a JavaScript error.       */

var powerlist = new Array(
new Array('Adapt Body', 'Psychometabolism', '', '', 'Psion/Wilder 5, Psychic Warrior 5', 'Visual', 'psionicPowersAtoC.html#adapt-body', 'Your body automatically adapts to hostile environments.'),
new Array('Affinity Field', 'Psychometabolism', '', '', 'Psion/Wilder 9', 'Material, Viaual', 'psionicPowersAtoC.html#affinity-field', 'Effects that affect you also affect others.'),
new Array('Anchored Navigation', 'Clairsentience', '', '', 'Seer 4', 'Material, Olfactory', 'psionicPowersAtoC.html#anchored-navigation', 'Establish a mishap-free teleport beacon.'),
new Array('Animal Affinity', 'Psychometabolism', '', '', 'Egoist 2, Psychic Warrior 2', 'Material', 'psionicPowersAtoC.html#animal-affinity', 'Gain +4 enhancement to one ability.'),
new Array('Apopsi', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 9', 'Auditory, Material, Visual', 'psionicPowersAtoC.html#apopsi', 'You delete targets psionic psionicPowers.'),
new Array('Assimilate', 'Psychomatabolism', '', '', 'Psion/Wilder 9', 'Auditory, Visual', 'psionicPowersAtoC.html#assimilate', 'Incorporate creature into your own body.'),
new Array('Astral Caravan', 'Psychoportation', '', '', 'Nomad 3', '', 'psionicPowersAtoC.html#astral-caravan', 'You lead astral traveler-enabled group to a planar destination.'),
new Array('Astral Construct', 'Metacreativity', 'Creation', '', 'Shaper 1', 'Visual', 'psionicPowersAtoC.html#astral-construct', 'Creates astral construct to fight for you.'),
new Array('Astral Seed', 'Metacreativity', '', '', 'Shaper 8', 'Material', 'psionicPowersAtoC.html#astral-seed', 'You plant the seed of your rebirth from the Astral Plane.'),
new Array('Astral Traveler', 'Psychoportation', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'None', 'psionicPowersAtoC.html#astral-traveler', 'Enable yourself or another to join an astral caravan-enabled trip.'),
new Array('Attraction', 'Telepathy', 'Charm', 'Mind-Affecting', 'Psion/Wilder 1', 'Auditory', 'psionicPowersAtoC.html#attraction', 'Subject has an attraction you specify.'),
new Array('Aura Alteration', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 6', 'Material', 'psionicPowersAtoC.html#aura-alteration', 'Repairs psyche or makes subject seem to be something it is not.'),
new Array('Aura Sight', 'Clairsentience', '', '', 'Psion/Wilder 4', 'Visual', 'psionicPowersAtoC.html#aura-sight', 'Reveals creatures, objects, psionicPowers, or spells of selected alignment axis.'),
new Array('Aversion', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Telepath 2', 'Auditory, Material', 'psionicPowersAtoC.html#aversion', 'Subject has aversion you specify.'),
new Array('Baleful Teleport', 'Psychoportation', 'Teleportation', '', 'Nomad 5', 'Material, Visual', 'psionicPowersAtoC.html#baleful-teleport', 'Destructive teleport deals 9d6 damage.'),
new Array('Banishment, Psionic', 'Psychoportation', '', '', 'Nomad 6', 'Auditory, Material', 'psionicPowersAtoC.html#banishment-psionic', 'Banishes extraplanar creatures.'),
new Array('Bend Reality', 'Clairsentience', '', '', 'Psion/Wilder 8', 'Visual', 'psionicPowersAtoC.html#bend-reality', 'Alters reality within power limits.'),
new Array('Bestow Power', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Mental', 'psionicPowersAtoC.html#bestow-power', 'Subject receives 2 power points.'),
new Array('Biofeedback', 'Psychometabolism', '', '', 'Psion/Wilder 2, Psychic Warrior 1', 'Material, Visual', 'psionicPowersAtoC.html#biofeedback', 'Gain damage reduction 2/-.'),
new Array('Bite of the Wolf', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Visual', 'psionicPowersAtoC.html#bite-of-the-wolf', 'Gain bite attack for 1d8 damage.'),
new Array('Body Adjustment', 'Psychometabolism', 'Healing', '', 'Psion/Wilder 3, Psychic Warrior 2', 'Auditory, Material', 'psionicPowersAtoC.html#body-adjustment', 'Heal 1d12 damage.'),
new Array('Body Equilibrium', 'Psychometabolism', '', '', 'Psion/Wilder 2, Psychic Warrior 2', 'Material, Visual', 'psionicPowersAtoC.html#body-equilibrium', 'You can walk on nonsolid surfaces.'),
new Array('Body Purification', 'Psychometabolism', 'Healing', '', 'Psion/Wilder 3, Psychic Warrior 2', 'Auditory, Material', 'psionicPowersAtoC.html#body-purification', 'Restore 2 points of ability damage.'),
new Array('Bolt', 'Metacreativity', 'Creation', '', 'Psion/Wilder 1', 'Material', 'psionicPowersAtoC.html#bolt', 'You create a few enhanced short-lived bolts, arrows, or bullets.'),
new Array('Brain Lock', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Telepath 2', 'Material, Visual', 'psionicPowersAtoC.html#brain-lock', 'Subject cannot move or take any mental actions.'),
new Array('Breath of the Black Dragon', 'Psychometabolism', '', 'Acid', 'Psion/Wilder 6, Psychic Warrior 6', 'Visual', 'psionicPowersAtoC.html#breath-of-the-black-dragon', 'Breathe acid for 11d6 damage.'),
new Array('Burst', 'Psychoportation', '', '', 'Nomad 1, Psychic Warrior 1', 'Auditory', 'psionicPowersAtoC.html#burst', 'Gain +10 ft. to speed this round.'),
new Array('Call to Mind', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Mental', 'psionicPowersAtoC.html#call-to-mind', 'Gain additional Knowledge check with +4 competence bonus.'),
new Array('Call Weaponry', 'Psychoportation', 'Teleportation', '', 'Psychic Warrior 1', 'Material', 'psionicPowersAtoC.html#call-weaponry', 'Create temporary weapon.'),
new Array('Catapsi', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 5, Psychic Warrior 5', 'Mental, Visual', 'psionicPowersAtoC.html#catapsi', 'Psychic static inhibits power manifestation.'),
new Array('Catfall', 'Psychoportation', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory', 'psionicPowersAtoC.html#catfall', 'Instantly save yourself from a fall.'),
new Array('Chameleon', 'Psychometabolism', '', '', 'Egoist 2, Psychic Warrior 1', 'Olfactory', 'psionicPowersAtoC.html#chameleon', 'Gain +10 enhancement bonus on Hide checks.'),
new Array('Charm, Psionic', 'Telepathy', 'Charm', 'Mind-Affecting', 'Telepath 1', 'Mental', 'psionicPowersAtoC.html#charm-psionic', 'Makes one person your friend.'),
new Array('Clairtangent Hand', 'Clairsentience', 'Scrying', '', 'Seer 5', 'Auditory, Mental, Visual', 'psionicPowersAtoC.html#clairtangent-hand', 'Emulate far hand at a distance.'),
new Array('Clairvoyant Sense', 'Clairsentience', 'Scrying', '', 'Seer 2', 'Auditory, Visual', 'psionicPowersAtoC.html#clairvoyant-sense', 'See and hear a distant location.'),
new Array('Claw of Energy', 'Psychokinesis', '', 'Cold, Electricity or Fire', 'Psychic Warrior 4', 'Visual', 'psionicPowersAtoC.html#claw-of-energy', 'Your claws deal additional energy damage.'),
new Array('Claws of the Beast', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Visual', 'psionicPowersAtoC.html#claws-of-the-beast', 'Your hands become deadly claws.'),
new Array('Claws of the Vampire', 'Psychometabolism', '', '', 'Psychic Warrior 3', 'Material, Visual', 'psionicPowersAtoC.html#claws-of-the-vampire', 'Heal half of your claws base damage.'),
new Array('Cloud Mind', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'None', 'psionicPowersAtoC.html#cloud-mind', 'You erase knowledge of your presence from targets mind.'),
new Array('Cloud Mind, Mass', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 6', 'None', 'psionicPowersAtoC.html#cloud-mind-mass', 'Erase knowledge of your presence from the minds of one creature/level.'),
new Array('Compression', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Olfactory', 'psionicPowersAtoC.html#compression', 'You grow smaller.'),
new Array('Conceal Thoughts', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1, Psychic Warrior 1', 'Mental', 'psionicPowersAtoC.html#conceal-thoughts', 'You conceal your motives.'),
new Array('Concealing Amorpha', 'Metacreativity', 'Creation', '', 'Psion/Wilder 2, Psychic Warrior 2', 'Material', 'psionicPowersAtoC.html#concealing-amorpha', 'Quasi-real membrane grants you concealment.'),
new Array('Concealing Amorpha, Greater', 'Metacreativity', 'Creation', '', 'Shaper 3, Psychic Warrior 3', 'Material', 'psionicPowersAtoC.html#concealing-amorpha-greater', 'Quasi-real membrane grants you total concealment.'),
new Array('Concussion Blast', 'Psychokinesis', '', 'Force', 'Psion/Wilder 2', 'Auditory', 'psionicPowersAtoC.html#concussion-blast', 'Deal 1d6 force damage to target.'),
new Array('Contingency, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 6', 'Olfactory', 'psionicPowersAtoC.html#contingency-psionic', 'Sets trigger condition for another power.'),
new Array('Control Air', 'Psychokinesis', '', '', 'Kineticist 2', 'Mental', 'psionicPowersAtoC.html#control-air', 'You have control over wind speed and direction.'),
new Array('Control Body', 'Psychokinesis', '', '', 'Kineticist 4', 'Material', 'psionicPowersAtoC.html#control-body', 'Take rudimentary control of your foes limbs.'),
new Array('Control Flames', 'Psychokinesis', '', 'Fire', 'Psion/Wilder 1', 'Auditory', 'psionicPowersAtoC.html#control-flames', 'Take control of nearby open flame.'),
new Array('Control Light', 'Psychokinesis', '', 'Light', 'Psion/Wilder 1', 'Visual', 'psionicPowersAtoC.html#control-light', 'Adjust ambient light levels.'),
new Array('Control Object', 'Psychokinesis', '', '', 'Kineticist 1', 'Material', 'psionicPowersAtoC.html#control-object', 'Telekinetically animate a small object.'),
new Array('Control Sound', 'Psychokinesis', '', 'Sonic', 'Psion/Wilder 2', 'Auditory', 'psionicPowersAtoC.html#control-sound', 'Create very specific sounds.'),
new Array('Co-Opt Concentration', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 6', 'Mental', 'psionicPowersAtoC.html#co-opt-concentration', 'Take control of foes concentration power.'),
new Array('Correspond', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 4', 'Mental', 'psionicPowersAtoC.html#correspond', 'Hold mental conversation with another creature at any distance.'),
new Array('Create Sound', 'Metacreativity', 'Creation', 'Sonic', 'Psion/Wilder 1', 'Auditory', 'psionicPowersAtoC.html#create-sound', 'Create the sound you desire.'),
new Array('Crisis of Breath', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Telepath 3', 'Auditory', 'psionicPowersAtoC.html#crisis-of-breath', 'Disrupt subjects breathing.'),
new Array('Crisis of Life', 'Telepathy', '', 'Mind-Affecting, Death', 'Telepath 7', 'Mental', 'psionicPowersAtoC.html#crisis-of-life', 'Stop subjects heart.'),
new Array('Crystal Shard', 'Metacreativity', 'Creation', '', 'Psion/Wilder 1', 'Auditory, Material', 'psionicPowersAtoC.html#crystal-shard', 'Ranged touch attack for 1d6 points of piercing damage.'),
new Array('Crystallize', 'Metacreativity', '', '', 'Shaper 6', 'Auditory', 'psionicPowersAtoC.html#crystallize', 'Turn subject permanently to crystal.'),
new Array('Danger Sense', 'Clairsentience', '', '', 'Psion/Wilder 3, Psychic Warrior 3', 'Visual', 'psionicPowersDtoF.html#danger-sense', 'You gain +4 bonus against traps.'),
new Array('Darkvision, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 3, Psychic Warrior 2', 'Visual', 'psionicPowersDtoF.html#darkvision-psionic', 'See 60 ft. in total darkness.'),
new Array('Daze, Psionic', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 1', 'Material, Mental', 'psionicPowersDtoF.html#daze-psionic', 'Humanoid creature of 4 HD or less loses next action.'),
new Array('Death Urge', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 4', 'Mental', 'psionicPowersDtoF.html#death-urge', 'Implant a self-destructive compulsion.'),
new Array('Deceleration', 'Psychoportation', '', '', 'Psion/Wilder 1', 'Auditory, Material', 'psionicPowersDtoF.html#deceleration', 'Targets speed is halved.'),
new Array('Decerebrate', 'Psychoportation', 'Teleportation', '', 'Psion/Wilder 7', 'Mental', 'psionicPowersDtoF.html#decerebration', 'Remove portion of subjects brain stem.'),
new Array('Dj Vu', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Mental', 'psionicPowersDtoF.html#deja-vu', 'Your target repeats his last action.'),
new Array('Demoralize', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Mental, Olfactory', 'psionicPowersDtoF.html#demoralize', 'Enemies become shaken.'),
new Array('Destiny Dissonance', 'Clairsentience', '', '', 'Seer 1', 'Material, Mental', 'psionicPowersDtoF.html#destiny-dissonance', 'Your dissonant touch sickens a foe.'),
new Array('Detect Hostile Intent', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2, Psychic Warrior 2', 'Olfactory', 'psionicPowersDtoF.html#detect-hostile-intent', 'You can detect hostile creatures within 30 ft. of you.'),
new Array('Detect Psionics', 'Clairsentience', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory, Visual', 'psionicPowersDtoF.html#detect-psionics', 'You detect the presence of psionics.'),
new Array('Detect Remote Viewing', 'Clairsentience', '', '', 'Psion/Wilder 4', 'Mental, Visual', 'psionicPowersDtoF.html#detect-remote-viewing', 'You know when others spy on you remotely.'),
new Array('Detect Teleportation', 'Clairsentience', '', '', 'Nomad 1', 'Visual', 'psionicPowersDtoF.html#detect-teleportation', 'Know when teleportation psionicPowers are used in close range.'),
new Array('Dimension Door, Psionic', 'Psychoportation', 'Teleportation', '', 'Psion/Wilder 4, Psychic Warrior 4', 'Visual', 'psionicPowersDtoF.html#dimension-door-psionic', 'Teleports you short distance.'),
new Array('Dimension Slide', 'Psychoportation', 'Teleportation', '', 'Psychic Warrior 3', 'Visual', 'psionicPowersDtoF.html#dimension-slide', 'Teleports you very short distance.'),
new Array('Dimension Swap', 'Psychoportation', 'Teleportation', '', 'Nomad 2, Psychic Warrior 2', 'Visual', 'psionicPowersDtoF.html#dimension-swap', 'You and an ally switch positions.'),
new Array('Dimensional Anchor, Psionic', 'Psychoportation', '', '', 'Nomad 4', 'Auditory', 'psionicPowersDtoF.html#dimensional-anchor-psionic', 'Bars extra dimensional movement.'),
new Array('Disable', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 1', 'Visual', 'psionicPowersDtoF.html#disable', 'Subjects incorrectly believe they are disabled.'),
new Array('Disintegrate, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 6', 'Auditory, Material, Visual', 'psionicPowersDtoF.html#disintegrate-psionic', 'Turn one creature or object to dust.'),
new Array('Dismissal, Psionic', 'Psychoportation', '', '', 'Nomad 4', 'Auditory', 'psionicPowersDtoF.html#dismissal-psionic', 'Forces a creature to return to its native plane.'),
new Array('Dismiss Ectoplasm', 'Metacreativity', '', '', 'Psion/Wilder 3', 'Auditory, Visual', 'psionicPowersDtoF.html#dismiss-ectoplasm', 'Dissipates ectoplasmic targets and effects.'),
new Array('Dispel Psionics', 'Psychokinesis', '', '', 'Psion/Wilder 3', 'Visual', 'psionicPowersDtoF.html#dispel-psionics', 'Cancels psionic psionicPowers and effects.'),
new Array('Dispelling Buffer', 'Psychokinesis', '', '', 'Kineticist 6, Psychic Warrior 6', 'Material, Olfactory', 'psionicPowersDtoF.html#dispelling-buffer', 'Subject is buffered from one dispel psionics effect.'),
new Array('Dissipating Touch', 'Psychoportation', 'Teleportation', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory, Visual', 'psionicPowersDtoF.html#dissipating-touch', 'Touch deals 1d6 damage.'),
new Array('Dissolving Touch', 'Psychometabolism', '', 'Acid', 'Psychic Warrior 2', 'Visual', 'psionicPowersDtoF.html#dissolving-touch', 'Your touch deals 4d6 acid damage.'),
new Array('Dissolving Weapon', 'Psychometabolism', '', 'Acid', 'Psychic Warrior 2', 'Visual', 'psionicPowersDtoF.html#dissolving-weapon', 'Your weapon deals 4d6 acid damage.'),
new Array('Distract', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1, Psychic Warrior 1', 'Mental', 'psionicPowersDtoF.html#distract', 'Subject gets -4 on Listen, Search, Sense Motive, and Spot checks.'),
new Array('Divert Teleport', 'Psychoportation', '', 'Teleportation', 'Psion/Wilder 7', 'Visual', 'psionicPowersDtoF.html#divert-teleport', 'Choose destination for anothers teleport.'),
new Array('Divination, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 4', 'Mental, Visual', 'psionicPowersDtoF.html#divination-psionic', 'Provides useful advice for specific proposed action.'),
new Array('Dominate, Psionic', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Telepath 4', 'Mental', 'psionicPowersDtoF.html#dominate-psionic', 'Control target telepathically.'),
new Array('Dream Travel', 'Psychoportation', '', '', 'Nomad 7', 'Visual', 'psionicPowersDtoF.html#dream-travel', 'Travel to other places through dreams.'),
new Array('Duodimensional Claw', 'Psychometabolism', '', '', 'Psychic Warrior 3', 'Material', 'psionicPowersDtoF.html#duodimensional-claw', 'Increases your natural weapons threat range.'),
new Array('Ecto Protection', 'Metacreativity', '', '', 'Psion/Wilder 1', 'Visual', 'psionicPowersDtoF.html#ecto-protection', 'An astral construct gains bonus against dismiss ectoplasm.'),
new Array('Ectoplasmic Cocoon', 'Metacreativity', '', '', 'Shaper 3', 'Auditory, Material', 'psionicPowersDtoF.html#ectoplasmic-cocoon', 'You encapsulate a foe so it cant move.'),
new Array('Ectoplasmic Cocoon, Mass', 'Metacreativity', '', '', 'Shaper 7', 'Auditory, Material', 'psionicPowersDtoF.html#ectoplasmic-cocoon-mass', 'You encapsulate all foes in a 20-ft. radius.'),
new Array('Ectoplasmic Form', 'Psychometabolism', '', '', 'Egosit 3, Psychic Warrior 3', 'Olfactory', 'psionicPowersDtoF.html#ectoplasmic-form', 'You gain benefits of being insubstantial and can fly slowly.'),
new Array('Ectoplasmic Shambler', 'Metacreativity', 'Creation', '', 'Psion/Wilder 5', 'Auditory, Material, Olfactory', 'psionicPowersDtoF.html#ectoplasmic-shambler', 'Foglike predator deals 1 point of damage/two levels each round to an area.'),
new Array('Ego Whip', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Auditory', 'psionicPowersDtoF.html#ego-whip', 'Deal 1d4 Cha damage and daze for 1 round.'),
new Array('Elfsight', 'Psychometabolism', '', '', 'Psion/Wilder 2, Psychic Warrior 1', 'Visual', 'psionicPowersDtoF.html#elfsight', 'Gain low-light vision, +2 bonus on Search and Spot checks, and notice secret doors.'),
new Array('Empathic Feedback', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 4, Psychic Warrior 3', 'Auditory, Material', 'psionicPowersDtoF.html#empathic-feedback', 'When you are hit in melee, your attacker takes damage.'),
new Array('Empathic Transfer', 'Psychometabolism', '', '', 'Egoist 2, Psychic Warrior 2', 'Auditory, Material', 'psionicPowersDtoF.html#empathic-transfer', 'Transfer anothers wounds to yourself.'),
new Array('Empathic Transfer, Hostile', 'Telepathy', '', 'Mind-Affecting', 'Telepath 3, Psychic Warrior 3', 'Auditory, Material', 'psionicPowersDtoF.html#empathic-transfer-hostile', 'Your touch transfers your hurt to another.'),
new Array('Empathy', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Mental', 'psionicPowersDtoF.html#empathy', 'You know the subjects surface emotions.'),
new Array('Empty Mind', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory', 'psionicPowersDtoF.html#empty-mind', 'You gain +2 on Will saves until your next action.'),
new Array('Energy Adaptation', 'Psychometabolism', '', 'Acid, Cold, Electricity, Fire or Sonic', 'Psion/Wilder 4, Psychic Warrior 4', 'Visual', 'psionicPowersDtoF.html#energy-adaptation', 'Your body converts energy to harmless light.'),
new Array('Energy Adaptation, Specified', 'Psychometabolism', '', 'Acid, Cold, Electricity, Fire or Sonic', 'Psion/Wilder 2, Psychic Warrior 2', 'Visual', 'psionicPowersDtoF.html#energy-adaptation', 'Gain resistance 10 against one energy type.'),
new Array('Energy Ball', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Kineticist 4', 'Auditory', 'psionicPowersDtoF.html#energy-ball', 'Deal 7d6 energy damage in 20-ft. radius.'),
new Array('Energy Bolt', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 3', 'Auditory', 'psionicPowersDtoF.html#energy-bolt', 'Deal 5d6 energy damage in 120-ft. line.'),
new Array('Energy Burst', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 3', 'Auditory', 'psionicPowersDtoF.html#energy-burst', 'Deal 5d6 energy damage in 40-ft. burst.'),
new Array('Energy Cone', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Kineticist 3', 'Auditory', 'psionicPowersDtoF.html#energy-cone', 'Deal 5d6 energy damage in 60-ft. cone.'),
new Array('Energy Conversion', 'Psychometabolism', '', 'Acid, Cold, Electricity, Fire or Sonic', 'Psion/Wilder 7', 'Mental', 'psionicPowersDtoF.html#energy-conversion', 'Offensively channel energy youve absorbed.'),
new Array('Energy Current', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Kineticist 5', 'Visual', 'psionicPowersDtoF.html#energy-current', 'Deal 9d6 damage to one foe and half to another foe as long as you concentrate.'),
new Array('Energy Missile', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Kineticist 2', 'Auditory', 'psionicPowersDtoF.html#energy-missile', 'Deal 3d6 energy damage to up to five subjects.'),
new Array('Energy Push', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 2', 'Auditory, Visual', 'psionicPowersDtoF.html#energy-push', 'Deal 2d6 damage and knock subject back.'),
new Array('Energy Ray', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 1', 'Auditory', 'psionicPowersDtoF.html#energy-ray', 'Deal 1d6 energy (cold, electricity, fire, or sonic) damage.'),
new Array('Energy Retort', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 3', 'Visual', 'psionicPowersDtoF.html#energy-retort', 'Ectoburst of energy automatically targets your attacker for 4d6 damage once each round.'),
new Array('Energy Stun', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 2', 'Auditory', 'psionicPowersDtoF.html#energy-stun', 'Deal 1d6 damage and stun target if it fails both saves.'),
new Array('Energy Wall', 'Metacreativity', 'Creation', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 3', 'Auditory', 'psionicPowersDtoF.html#energy-wall', 'Create wall of your chosen energy type.'),
new Array('Energy Wave', 'Psychokinesis', '', 'Cold, Electricity, Fire or Sonic', 'Psion/Wilder 7', 'Auditory', 'psionicPowersDtoF.html#energy-wave', 'Deal 13d4 damage of your chosen energy type in 120-ft. cone.'),
new Array('Entangling Ectoplasm', 'Metacreativity', 'Creation', '', 'Psion/Wilder 1', 'Material, Visual', 'psionicPowersDtoF.html#entangling-ectoplasm', 'You entangle a foe in sticky goo.'),
new Array('Eradicate Invisibility', 'Psychokinesis', '', '', 'Psion/Wilder 3', 'Visual', 'psionicPowersDtoF.html#eradicate-invisibility', 'Negate invisibility in 50-ft. burst.'),
new Array('Escape Detection', 'Clairsentience', '', '', 'Psychic Warrior 3, Seer 3', 'None', 'psionicPowersDtoF.html#escape-detection', 'You become difficult to detect with clairsentience psionicPowers.'),
new Array('Ethereal Jaunt, Psionic', 'Psychoportation', '', '', 'Nomad 7', 'Visual', 'psionicPowersDtoF.html#ethereal-jaunt-psionic', 'Become ethereal for 1 round/level.'),
new Array('Etherealness, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 9', '', 'psionicPowersDtoF.html#etherealness-psionic', 'Become ethereal for 1 min./level.'),
new Array('Evade Burst', 'Psychometabolism', '', '', 'Psion/Wilder 7, Psychic Warrior 3', 'Material', 'psionicPowersDtoF.html#evade-burst', 'You take no damage from a burst on a successful Reflex save.'),
new Array('Exhalation of the Black Dragon', 'Psychometabolism', '', 'Acid', 'Psychic Warrior 3', 'Visual', 'psionicPowersDtoF.html#exhalation-of-the-black-dragon', 'Your acid breath deals 3d6 damage to a close target.'),
new Array('Expansion', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Olfactory', 'psionicPowersDtoF.html#expansion', 'Become one size category larger.'),
new Array('Fabricate, Psionic', 'Metacreativity', 'Creation', '', 'Shaper 4', 'Material', 'psionicPowersDtoF.html#fabricate-psionic', 'Transforms raw goods to finished items.'),
new Array('Fabricate, Greater Psionic', 'Metacreativity', 'Creation', '', 'Shaper 6', 'Material', 'psionicPowersDtoF.html#fabricate-greater-psionic', 'Transforms a lot of raw goods to finished items.'),
new Array('False Sensory Input', 'Telepathy', '', 'Mind-Affecting', 'Telepath 3', 'Mental', 'psionicPowersDtoF.html#false-sensory-input', 'Subject sees what isnt there.'),
new Array('Far Hand', 'Psychokinesis', '', '', 'Psion/Wilder 1', 'Visual', 'psionicPowersDtoF.html#far-hand', 'Move small objects at a limited distance.'),
new Array('Fate Link', 'Clairsentience', '', '', 'Seer 3', 'Olfactory', 'psionicPowersDtoF.html#fate-link', 'You link the fates of two targets.'),
new Array('Fate of One', 'Clairsentience', '', '', 'Seer 7', 'Mental, Visual', 'psionicPowersDtoF.html#fate-of-one', 'Reroll any roll you just failed.'),
new Array('Feat Leech', 'Clairsentience', '', '', 'Psion/Wilder 2, Psychic Warrior 2', 'Mental, Visual', 'psionicPowersDtoF.html#feat-leech', 'Borrow anothers psionic or metapsionic feats.'),
new Array('Fiery Discorporation', 'Psychokinesis', '', 'Fire', 'Kineticist 5', 'Visual', 'psionicPowersDtoF.html#fiery-discorporation', 'Cheat death by discorporating into nearby fire for one day.'),
new Array('Fission', 'Psychometabolism', '', '', 'Egoist 7', 'Olfactory', 'psionicPowersDtoF.html#fission', 'You briefly duplicate yourself.'),
new Array('Float', 'Psychoportation', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory', 'psionicPowersDtoF.html#float', 'You buoy yourself in water or other liquid.'),
new Array('Fly, Psionic', 'Psychoportation', '', '', 'Nomad 4', 'Auditory', 'psionicPowersDtoF.html#fly-psionic', 'You fly at a speed of 60 ft.'),
new Array('Force Screen', 'Psychokinesis', '', 'Force', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory', 'psionicPowersDtoF.html#force-screen', 'Invisible disc provides +4 shield bonus to AC.'),
new Array('Form of Doom', 'Psychometabolism', '', '', 'Psychic Warrior 6', 'Visual', 'psionicPowersDtoF.html#form-of-doom', 'You transform into a frightening tentacled beast.'),
new Array('Freedom of Movement, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 4, Psychic Warrior 4', 'Auditory', 'psionicPowersDtoF.html#freedom-of-movement-psionic', 'You cannot be held or otherwise rendered immobile.'),
new Array('Fuse Flesh', 'Psychometabolism', '', '', 'Psion/Wilder 6', 'Visual', 'psionicPowersDtoF.html#fuse-flesh', 'Fuse subjects flesh, creating a helpless mass.'),
new Array('Fusion', 'Psychometabolism', '', '', 'Egoist 8', 'Auditory, Material, Visual', 'psionicPowersDtoF.html#fusion', 'You combine your abilities and form with another.'),
new Array('Genesis', 'Metacreativity', 'Creation', '', 'Shaper 9', 'Material', 'psionicPowersGtoP.html#genesis', 'You instigate a new demiplane on the Astral Plane.'),
new Array('Graft Weapon', 'Psychometabolism', '', '', 'Psychic Warrior 3', 'Olfactory', 'psionicPowersGtoP.html#graft-weapon', 'Your hand is replaced seamlessly by your weapon.'),
new Array('Grease, Psionic', 'Metacreativity', 'Creation', '', 'Psion/Wilder 1', 'Olfactory, Visual', 'psionicPowersGtoP.html#grease-psionic', 'Makes 10-ft. square or one object slippery.'),
new Array('Grip of Iron', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Visual', 'psionicPowersGtoP.html#grip-of-iron', 'Your iron grip gives +4 bonus on grapple checks.'),
new Array('Hail of Crystals', 'Metacreativity', 'Creation', '', 'Shaper 5', 'Auditory, Visual', 'psionicPowersGtoP.html#hail-of-crystals', 'A crystal explodes in an area, dealing 9d4 slashing damage.'),
new Array('Hammer', 'Psychometabolism', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory, Material', 'psionicPowersGtoP.html#hammer', 'Melee touch attack deals 1d8/round.'),
new Array('Hustle', 'Psychometabolism', '', '', 'Egoist 3, Psychic Warrior 2', 'Auditory', 'psionicPowersGtoP.html#hustle', 'Instantly gain a move action.'),
new Array('Hypercognition', 'Clairsentience', '', '', 'Seer 8', 'Mental', 'psionicPowersGtoP.html#hypercognition', 'You can deduce almost anything.'),
new Array('Id Insinuation', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 2', 'Auditory', 'psionicPowersGtoP.html#id-insinuation', 'Swift tendrils of thought disrupt and confuse your target.'),
new Array('Identify, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 2', 'Material, Mental', 'psionicPowersGtoP.html#identify-psionic', 'Learn the properties of a psionic item.'),
new Array('Immovability', 'Psychometabolism', '', '', 'Psychic Warrior 4', 'Visual', 'psionicPowersGtoP.html#immovability', 'You are almost impossible to move and gain DR 15/-.'),
new Array('Incarnate', 'Metacreativity', '', '', 'Psion/Wilder 5', 'Material', 'psionicPowersGtoP.html#incarnate', 'Make some psionicPowers permanent.'),
new Array('Inertial Armor', 'Psychokinesis', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Visual', 'psionicPowersGtoP.html#inertial-armor', 'Tangible field of force provides you with +4 armor bonus to AC.'),
new Array('Inertial Barrier', 'Psychokinesis', '', '', 'Kineticist 4, Psychic Warrior 4', 'Auditory, Mental', 'psionicPowersGtoP.html#inertial-barrier', 'Gain DR 5/-.'),
new Array('Inflict Pain', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Mental', 'psionicPowersGtoP.html#inflict-pain', 'Telepathic stab gives your foe -4 on attack rolls, or -2 if he makes the save.'),
new Array('Insanity', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 7', 'Mental', 'psionicPowersGtoP.html#insanity', 'Subject is permanently confused.'),
new Array('Intellect Fortress', 'Psychokinesis', '', '', 'Psion/Wilder 4', 'Auditory', 'psionicPowersGtoP.html#intellect-fortress', 'Those inside fortress take only half damage from all psionicPowers and psi-like abilities until your next action.'),
new Array('Iron Body, Psionic', 'Metacreativity', 'Creation', '', 'Psion/Wilder 8', 'Auditory', 'psionicPowersGtoP.html#iron-body-psionic', 'Your body becomes living iron.'),
new Array('Keen Edge, Psionic', 'Metacreativity', '', '', 'Psion/Wilder 3, Psychic Warrior 3', 'Visual', 'psionicPowersGtoP.html#keen-edge-psionic', 'Doubles normal weapons threat range.'),
new Array('Knock, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 2', 'Material', 'psionicPowersGtoP.html#knock-psionic', 'Opens locked or psionically sealed door.'),
new Array('Know Direction and Location', 'Clairsentience', '', '', 'Psion/Wilder 1', 'Mental', 'psionicPowersGtoP.html#know-direction-and-location', 'You discover where you are and what direction you face.'),
new Array('Leech Field', 'Psychometabolism', '', '', 'Psion/Wilder 5', 'Visual', 'psionicPowersGtoP.html#leech-field', 'Leech power points each time you make a saving throw.'),
new Array('Levitate, Psionic', 'Psychoportation', '', '', 'Nomad 2, Psion/Wilder 2, Psychic Warrior 2', 'Olfactory', 'psionicPowersGtoP.html#levitate-psionic', 'You move up and down, forward and back via mental support.'),
new Array('Major Creation, Psionic', 'Metacreativity', 'Creation', '', 'Psion/Wilder 5', '', 'psionicPowersGtoP.html#major-creation-psionic', 'As psionic minor creation, plus stone and metal.'),
new Array('Matter Agitation', 'Psychokinesis', '', '', 'Psion/Wilder 1', 'Auditory, Material', 'psionicPowersGtoP.html#matter-agitation', 'You heat a creature or object.'),
new Array('Matter Manipulation', 'Metacreativity', '', '', 'Psion/Wilder 8', 'Auditory, Mental', 'psionicPowersGtoP.html#matter-manipulation', 'Increase or decrease an objects base hardness by 5.'),
new Array('Mental Barrier', 'Clairentience', '', '', 'Psion/Wilder 3, Psychic Warrior 3', 'Auditory', 'psionicPowersGtoP.html#mental-barrier', 'Gain +4 deflection bonus to AC until your next action.'),
new Array('Mental Disruption', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Mental', 'psionicPowersGtoP.html#mental-disruption', 'Daze creatures within 10 feet for 1 round.'),
new Array('Metaconcert', 'Telepathy', '', 'Mind-Affecting', 'Psychic Warrior 5, Telepath 5', 'Visual', 'psionicPowersGtoP.html#metaconcert', 'Mental concert of two or more increases the total power of the participants.'),
new Array('Metafaculty', 'Clairsentience', '', '', 'Seer 9', 'Mental, Olfactory, Visual', 'psionicPowersGtoP.html#metafaculty', 'You learn details about any one creature.'),
new Array('Metamorphosis', 'Psychometabolism', '', '', 'Egoist 4', 'Material, Olfactory', 'psionicPowersGtoP.html#metamorphosis', 'Assume shape of creature or object.'),
new Array('Metamorphosis, Greater', 'Psychometabolism', '', '', 'Egoist 9', 'Material, Visual', 'psionicPowersGtoP.html#metamorphosis-greater', 'Assume shape of any nonunique creature or object each round.'),
new Array('Metaphysical Claw', 'Psychometabolism', '', '', 'Psychic Warrior 1', 'Auditory', 'psionicPowersGtoP.html#metaphysical-claw', 'Your natural weapon gains +1 bonus.'),
new Array('Metaphysical Weapon', 'Metacreativity', '', '', 'Psychic Warrior 1', 'Auditory', 'psionicPowersGtoP.html#metaphysical-weapon', 'Weapon gains +1 bonus.'),
new Array('Microcosm', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 9', 'Material', 'psionicPowersGtoP.html#microcosm', 'Creature or creature lives forevermore in world of his own imagination.'),
new Array('Mind Blank, Personal', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 7, Psychic Warrior 6', 'Olfactory', 'psionicPowersGtoP.html#mind-blank-personal', 'You are immune to scrying and mental effects.'),
new Array('Mind Blank, Psionic', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 8', 'Olfactory', 'psionicPowersGtoP.html#mind-blank-psionic', 'Subject immune to mental/emotional effects, scrying, and remote viewing.'),
new Array('Mind Probe', 'Telepathy', 'Charm', 'Mind-Affecting', 'Telepath 5', 'Auditory, Material, Visual', 'psionicPowersGtoP.html#mind-probe', 'You discover the subjects secret thoughts.'),
new Array('Mind Seed', 'Telepathy', 'Compulsion', 'Evil, Mind-Affecting', 'Telepath 8', 'Mental', 'psionicPowersGtoP.html#mind-seed', 'Subject slowly becomes you.'),
new Array('Mind Switch', 'Telepathy', '', 'Mind-Affecting', 'Telepath 6', 'Visual', 'psionicPowersGtoP.html#mind-switch', 'You switch minds with another.'),
new Array('Mind Switch, True', 'Telepathy', '', 'Mind-Affecting', 'Telepath 9', 'Visual', 'psionicPowersGtoP.html#mind-switch-true', 'A permanent brain swap.'),
new Array('Mind Thrust', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Auditory', 'psionicPowersGtoP.html#mind-thrust', 'Deal 1d10 damage.'),
new Array('Mind Trap', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 3', 'Auditory', 'psionicPowersGtoP.html#mind-trap', 'Drain 1d6 power points from anyone who attacks you with a telepathy power.'),
new Array('Mindlink', 'Telepathy', '', 'Mind-Affecting', 'Telepath 1', 'Mental', 'psionicPowersGtoP.html#mindlink', 'You forge a limited mental bond with another creature.'),
new Array('Mindlink, Thieving', 'Telepathy', '', 'Mind-Affecting', 'Telepath 4', 'Mental', 'psionicPowersGtoP.html#mindlink-thieving', 'Borrow knowledge of a subjects power.'),
new Array('Mindswipe', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 4', 'Auditory, Mental, Visual', 'psionicPowersGtoP.html#mindswipe', 'Subjects recent experiences wiped away, bestowing negative levels.'),
new Array('Minor Creation, Psionic', 'Metacreativity', 'Creation', '', 'Shaper 1', 'Material', 'psionicPowersGtoP.html#minor-creation-psionic', 'Creates one cloth or wood object.'),
new Array('Missive', 'Telepathy', '', 'Mind-Affecting, Language-Dependent', 'Psion/Wilder 1', 'Mental', 'psionicPowersGtoP.html#missive', 'Send a one-way telepathic message to subject.'),
new Array('Missive, Mass', 'Telepathy', '', 'Mind-Affecting, Language-Dependent', 'Psion/Wilder 2', 'Mental', 'psionicPowersGtoP.html#missive-mass', 'You send a one-way telepathic message to an area.'),
new Array('Modify Memory, Psionic', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Telepath 4', 'Mental', 'psionicPowersGtoP.html#modify-memory-psionic', 'Changes 5 minutes of subjects memories.'),
new Array('Moment of Prescience, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 7', 'Visual', 'psionicPowersGtoP.html#moment-of-prescience-psionic', 'You gain insight bonus on single attack roll, check, or save.'),
new Array('My Light', 'Psychokinesis', '', 'Light', 'Psion/Wilder 1, Psychic Warrior 1', 'Auditory, Visual', 'psionicPowersGtoP.html#my-light', 'Your eyes emit 20-ft. cone of light.'),
new Array('Null Psionic Field', 'Psychokinesis', '', '', 'Kineticist 6', 'Auditory, Visual', 'psionicPowersGtoP.html#null-psionic-field', 'Create a field where psionic power does not function.'),
new Array('Oak Body', 'Psychometabolism', '', '', 'Psion/Wilder 7, Psychic Warrior 5', 'Auditory', 'psionicPowersGtoP.html#oak-body', 'Your body becomes as hard as oak.'),
new Array('Object Reading', 'Clairsentience', '', '', 'Seer 2', 'Auditory, Material', 'psionicPowersGtoP.html#object-reading', 'Learn details about an objects previous owner.'),
new Array('Overland Flight, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 6', 'Auditory', 'psionicPowersGtoP.html#overland-flight-psionic', 'You fly at a speed of 40 ft. and can hustle over long distances.'),
new Array('Painful Strike', 'Psychometabolism', '', '', 'Psychic Warrior 2', 'Material, Visual', 'psionicPowersGtoP.html#painful-strike', 'Your natural weapons deal an extra 1d6 nonlethal damage.'),
new Array('Personality Parasite', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 4', 'Auditory, Visual', 'psionicPowersGtoP.html#personality-parasite', 'Subjects mind calves self-antagonistic splinter personality for 1 round/level.'),
new Array('Phase Door, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 7', 'Visual', 'psionicPowersGtoP.html#phase-door-psionic', 'Invisible passage through wood or stone.'),
new Array('Plane Shift, Psionic', 'Psychoportation', '', '', 'Psion/Wilder 5', 'Visual', 'psionicPowersGtoP.html#plane-shift-psionic', 'Travel to other planes.'),
new Array('Power Leech', 'Telepathy', 'Compulsion', 'Mind-Affecting', 'Psion/Wilder 4', 'Visual', 'psionicPowersGtoP.html#power-leech', 'Drain 1d6 power points/round while you maintain concentration; you gain 1/round.'),
new Array('Power Resistance', 'Clairsentience', '', '', 'Psion/Wilder 5', 'Material, Visual', 'psionicPowersGtoP.html#power-resistance', 'Grant PR equal to 12 + level.'),
new Array('Precognition', 'Clairsentience', '', '', 'Seer 1', 'Visual', 'psionicPowersGtoP.html#precognition', 'Gain +2 insight bonus to one roll.'),
new Array('Precognition, Defensive', 'Clairsentience', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material, Visual', 'psionicPowersGtoP.html#precognition-defensive', 'Gain +1 insight bonus to AC and saving throws.'),
new Array('Precognition, Greater', 'Clairsentience', '', '', 'Seer 6', 'Auditory, Visual', 'psionicPowersGtoP.html#precognition-greater', 'Gain +4 insight bonus to one roll.'),
new Array('Precognition, Offensive', 'Clairsentience', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material, Visual', 'psionicPowersGtoP.html#precognition-offensive', 'Gain +1 insight bonus on your attack rolls.'),
new Array('Prescience, Offensive', 'Clairsentience', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material, Visual', 'psionicPowersGtoP.html#prescience-offensive', 'Gain +2 insight bonus on your damage rolls.'),
new Array('Prevenom', 'Psychometabolism', 'Creation', '', 'Psychic Warrior 1', 'Material', 'psionicPowersGtoP.html#prevenom', 'Your claws gain a poison coating.'),
new Array('Prevenom Weapon', 'Psychometabolism', 'Creation', '', 'Psychic Warrior 1', 'Material', 'psionicPowersGtoP.html#prevenom-weapon', 'Your weapon is mildly venomous.'),
new Array('Prowess', 'Clairsentience', '', '', 'Psychic Warrior 2', 'Mental', 'psionicPowersGtoP.html#prowess', 'Instantly gain another attack of opportunity.'),
new Array('Psionic Blast', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 3', 'Auditory', 'psionicPowersGtoP.html#psionic-blast', 'Stun creatures in 30-ft. cone for 1 round.'),
new Array('Psionic Lion\'s Charge', 'Psychometabolism', '', '', 'Psychic Warrior 2', 'Mental', 'psionicPowersGtoP.html#psionic-lions-charge', 'You can make full attack in same round you charge.'),
new Array('Psionic Lock', 'Psychoportation', '', '', 'Psion/Wilder 2', 'Material', 'psionicPowersGtoP.html#psionic-lock', 'Secure a door, chest, or portal.'),
new Array('Psionic Repair Damage', 'Metacreativity', '', '', 'Shaper 2', 'Material, Visual', 'psionicPowersGtoP.html#psionic-repair-damage', 'Repairs construct of 3d8 hit points +1 hp/level.'),
new Array('Psionic Revivify', 'Psychometabolism', 'Healing', 'Good', 'Egoist 5', '', 'psionicPowersGtoP.html#psionic-revivify', 'Return the dead to life before the psyche leaves the corpse.'),
new Array('Psionic Scent', 'Psychometabolism', '', '', 'Psychic Warrior 2', 'Mental', 'psionicPowersGtoP.html#psionic-scent', 'Gain the scent ability.'),
new Array('Psychic Chirurgery', 'Telepathy', '', 'Mind-Affecting', 'Telepathy 9', 'Auditory, Mental, Visual', 'psionicPowersGtoP.html#psychic-chirurgery', 'You repair psychic damage or impart knowledge of new psionicPowers.'),
new Array('Psychic Crush', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 5', 'Auditory', 'psionicPowersGtoP.html#psychic-crush', 'Brutally crush subjects mental essence, reducing subject to -1 hit points.'),
new Array('Psychic Reformation', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 4', 'Auditory, Mental, Visual', 'psionicPowersGtoP.html#psychic-reformation', 'Subject can choose skills, feats, and psionicPowers anew for previous levels.'),
new Array('Psychic Vampire', 'Psychometabolism', '', '', 'Egoist 4, Psychic Warrior 4', 'Mental', 'psionicPowersGtoP.html#psychic-vampire', 'Touch attack drains 2 power points/level from foe.'),
new Array('Psychofeedback', 'Psychometabolism', '', '', 'Egoist 5, Psychic Warrior 5', 'Visual', 'psionicPowersGtoP.html#psychofeedback', 'Boost Strength, Dexterity, or Constitution at the expense of one or more other scores.'),
new Array('Quintessence', 'Metacreativity', 'Creation', '', 'Shaper 4', 'Material', 'psionicPowersQtoW.html#quintessence', 'You collapse a bit of time into a physical substance.'),
new Array('Read Thoughts', 'Telepathy', '', 'Mind-Affecting', 'Telepath 2', 'Mental', 'psionicPowersQtoW.html#read-thoughts', 'Detect surface thoughts of creatures in range.'),
new Array('Reality Revision', 'Clairsentience', '', '', 'Psion/Wilder 9', 'Visual', 'psionicPowersQtoW.html#reality-revision', 'As bend reality, but fewer limits.'),
new Array('Recall Agony', 'Clairsentience', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Material', 'psionicPowersQtoW.html#recall-agony', 'Foe takes 2d6 damage.'),
new Array('Recall Death', 'Clairsentience', '', 'Death, Mind-Affecting', 'Psion/Wilder 8', 'Material', 'psionicPowersQtoW.html#recall-death', 'Subject dies or takes 5d6 damage.'),
new Array('Reddopsi', 'Psychokinesis', '', '', 'Kineticist 7', 'Auditory, Mental, Olfactory', 'psionicPowersQtoW.html#reddopsi', 'psionicPowers targeting you rebound on manifester.'),
new Array('Remote View Trap', 'Clairsentience', '', 'Electricity', 'Psion/Wilder 6', 'Mental, Visual', 'psionicPowersQtoW.html#remote-view-trap', 'Deal 8d6 points electricity damage to those who seek to view you at a distance.'),
new Array('Remote Viewing', 'Clairsentience', '', 'Scrying', 'Seer 4', 'Mental', 'psionicPowersQtoW.html#remote-viewing', 'See, hear, and potentially interact with subjects at a distance.'),
new Array('Restoration, Psionic', 'Psychometabolism', 'Healing', '', 'Egoist 6', 'Material', 'psionicPowersQtoW.html#restoration-psionic', 'Restores level and ability score drains.'),
new Array('Restore Extremity', 'Psychometabolism', 'Healing', '', 'Egoist 5', 'Auditory', 'psionicPowersQtoW.html#restore-extremity', 'Return a lost digit, limb, or other appendage to subject.'),
new Array('Retrieve', 'Psychoportation', 'Teleportation', '', 'Psion/Wilder 6', 'Visual', 'psionicPowersQtoW.html#retrieve', 'Teleport to your hand an item you can see.'),
new Array('Schism', 'Telepathy', '', 'Mind-Affecting', 'Telepath 4', 'Auditory, Visual', 'psionicPowersQtoW.html#schism', 'Your partitioned mind can manifest lower level psionicPowers.'),
new Array('Second Chance', 'Clairsentience', '', '', 'Seer 5', 'Mental', 'psionicPowersQtoW.html#second-chance', 'Gain a reroll.'),
new Array('Sense Link', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 1', 'Visual', 'psionicPowersQtoW.html#sense-link', 'You sense what the subject senses (single sense).'),
new Array('Sense Link, Forced', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'Visual', 'psionicPowersQtoW.html#sense-link-forced', 'Sense what subject senses.'),
new Array('Sensitivity to Psychic Impressions', 'Clairsentience', '', '', 'Seer 2', 'Auditory, Material', 'psionicPowersQtoW.html#sensitivity-to-psychic-impressions', 'You can find out about an areas past.'),
new Array('Sequester, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 7', 'None', 'psionicPowersQtoW.html#sequester-psionic', 'Subject invisible to sight and remote viewing; renders subject comatose.'),
new Array('Shadow Body', 'Psychometabolism', '', '', 'Psion/Wilder 8', 'Auditory', 'psionicPowersQtoW.html#shadow-body', 'You become a living shadow (not the creature).'),
new Array('Share Pain', 'Psychometabolism', '', '', 'Psion/Wilder 2', 'Material, Mental', 'psionicPowersQtoW.html#share-pain', 'Willing subject takes some of your damage.'),
new Array('Share Pain, Forced', 'Psychometabolism', '', '', 'Psion/Wilder 3', 'Material, Mental', 'psionicPowersQtoW.html#share-pain-forced', 'Unwilling subject takes some of your damage.'),
new Array('Shatter Mind Blank', 'Telepathy', '', '', 'Psion/Wilder 5', 'Olfactory', 'psionicPowersQtoW.html#shatter-mind-blank', 'Cancels targets mind blank effect.'),
new Array('Skate', 'Psychoportation', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material, Visual', 'psionicPowersQtoW.html#skate', 'Subject slides skillfully along the ground.'),
new Array('Solicit Psicrystal', 'Telepathy', '', '', 'Psion/Wilder 3', 'Auditory', 'psionicPowersQtoW.html#solicit-psicrystal', 'Your psicrystal takes over your concentration power.'),
new Array('Steadfast Perception', 'Clairsentience', '', '', 'Psychic Warrior 4', 'Visual', 'psionicPowersQtoW.html#steadfast-perception', 'Gain immunity to illusory effects, +6 bonus on Spot and Search checks.'),
new Array('Stomp', 'Psychokinesis', '', '', 'Psychic Warrior 1', 'Auditory, Visual', 'psionicPowersQtoW.html#stomp', 'Subjects fall prone and take 1d4 nonlethal damage.'),
new Array('Strength of My Enemy', 'Psychometabolism', '', '', 'Psychic Warrior 2', 'Visual', 'psionicPowersQtoW.html#strength-of-my-enemy', 'Siphon away your enemys strength and grow stronger.'),
new Array('Suggestion, Psionic', 'Telepathy', 'Compulsion', 'Mind-Affecting, Language-Dependent', 'Telepath 2', 'Auditory', 'psionicPowersQtoW.html#suggestion-psionic', 'Compels subject to follow stated course of action.'),
new Array('Suspend Life', 'Psychometabolism', '', '', 'Psion/Wilder 6, Psychic Warrior 6', 'Olfactory', 'psionicPowersQtoW.html#suspend-life', 'Put yourself in a state akin to suspended animation.'),
new Array('Sustenance', 'Psychometabolism', '', '', 'Psion/Wilder 2, Psychic Warrior 2', 'Material', 'psionicPowersQtoW.html#sustenance', 'Go without food and water for one day.'),
new Array('Swarm of Crystals', 'Metacreativity', 'Creation', '', 'Psion/Wilder 2', 'Material', 'psionicPowersQtoW.html#swarm-of-crystals', 'Crystal shards are sprayed forth doing 3d4 slashing damage.'),
new Array('Synesthete', 'Psychometabolism', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material', 'psionicPowersQtoW.html#synesthete', 'You receive one kind of sense when another sense is stimulated.'),
new Array('Telekinetic Force', 'Psychokinesis', '', 'Force', 'Psion/Wilder 3', 'Visual', 'psionicPowersQtoW.html#telekinetic-force', 'Move an object with the sustained force of your mind.'),
new Array('Telekinetic Maneuver', 'Psychokinesis', '', 'Force', 'Psion/Wilder 4', 'Visual', 'psionicPowersQtoW.html#telekinetic-maneuver', 'Telekinetically bull rush, disarm, grapple, or trip your target.'),
new Array('Telekinetic Sphere, Psionic', 'Psychokinesis', '', 'Force', 'Kineticist 8', 'Material', 'psionicPowersQtoW.html#telekinetic-sphere-psionic', 'Mobile force globe encapsulates creature and moves it.'),
new Array('Telekinetic Thrust', 'Psychokinesis', '', '', 'Psion/Wilder 3', 'Visual', 'psionicPowersQtoW.html#telekinetic-thrust', 'Hurl objects with the force of your mind.'),
new Array('Telempathic Projection', 'Telepathy', 'Charm', 'Mind-Affecting', 'Psion/Wilder 1', 'Visual', 'psionicPowersQtoW.html#telempathic-projection', 'Alter the subjects mood.'),
new Array('Teleport, Psionic', 'Psychoportation', 'Teleportation', '', 'Nomad 5', 'Visual', 'psionicPowersQtoW.html#teleport-psionic', 'Instantly transports you as far as 100 miles/level.'),
new Array('Teleport, Psionic Greater', 'Psychoportation', 'Teleportation', '', 'Psion/Wilder 8', 'Visual', 'psionicPowersQtoW.html#teleport-psionic-greater', 'As psionic teleport, but no range limit and no off-target arrival.'),
new Array('Teleportation Circle, Psionic', 'Psychoportation', 'Teleportation', '', 'Nomad 9', 'Mental', 'psionicPowersQtoW.html#teleportation-circle-psionic', 'Circle teleports any creatures inside to designated spot.'),
new Array('Teleport Trigger', 'Psychoportation', 'Teleportation', '', 'Nomad 5', 'Material', 'psionicPowersQtoW.html#teleport-trigger', 'Predetermined event triggers teleport.'),
new Array('Temporal Acceleration', 'Psychoportation', '', '', 'Psion/Wildere 6', 'None', 'psionicPowersQtoW.html#temporal-acceleration', 'Your time frame accelerates for 1 round.'),
new Array('Thicken Skin', 'Psychometabolism', '', '', 'Egoist 1, Psychic Warrior 1', 'Material, Olfactory', 'psionicPowersQtoW.html#thicken-skin', 'Gain +1 enhancement bonus to your AC for 10 min./level.'),
new Array('Thought Shield', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2, Psychic Warrior 2', 'Auditory', 'psionicPowersQtoW.html#thought-shield', 'Gain PR 13 against mind-affecting psionicPowers.'),
new Array('Time Hop', 'Psychoportation', '', '', 'Psion/Wilder 3', 'Auditory, Visual', 'psionicPowersQtoW.html#time-hop', 'Subject hops forward in time 1 round/level.'),
new Array('Time Hop, Mass', 'Psychoportation', '', '', 'Nomad 8', 'Auditory, Visual', 'psionicPowersQtoW.html#time-hop-mass', 'Willing subjects hop forward in time.'),
new Array('Time Regression', 'Psychoportation', '', '', 'Nomad 9', 'None', 'psionicPowersQtoW.html#time-regression', 'Relive the last round.'),
new Array('Timeless Body', 'Psychoportation', '', '', 'Psion/Wilder 9', 'Material', 'psionicPowersQtoW.html#timeless-body', 'Ignore all harmful, and helpful, effects for 1 round.'),
new Array('Tongues, Psionic', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 2', 'None', 'psionicPowersQtoW.html#tongues-psionic', 'You can communicate with intelligent creatures.'),
new Array('Tornado Blast', 'Psychokinesis', '', '', 'Kineticist 9', 'Auditory, Visual', 'psionicPowersQtoW.html#tornado-blast', 'Vortex of air subjects your foes to 17d6 damage and moves them.'),
new Array('Touchsight', 'Psychometabolism', '', '', 'Psion/Wilder 3', 'Visual', 'psionicPowersQtoW.html#touchsight', 'Your telekinetic field tells you where everything is.'),
new Array('Tower of Iron Will', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 5', 'Auditory', 'psionicPowersQtoW.html#tower-of-iron-will', 'Grant PR 19 against mind-affecting psionicPowers to all creatures within 10 ft. until your next turn.'),
new Array('Trace Teleport', 'Clairsentience', '', '', 'Psion/Wilder 4', 'Visual', 'psionicPowersQtoW.html#trace-teleport', 'Learn destination of subjects teleport.'),
new Array('True Creation', 'Metacreativity', 'Creation', '', 'Shaper 9', '', 'psionicPowersQtoW.html#true-creation', 'As psionic major creation, except items are completely real.'),
new Array('True Metabolism', 'Psychometabolism', '', '', 'Psion/Wilder 8', 'Material', 'psionicPowersQtoW.html#true-metabolism', 'You regenerate 10 hit points/round.'),
new Array('True Seeing, Psionic', 'Clairsentience', '', '', 'Psion/Wilder 5', 'Visual', 'psionicPowersQtoW.html#true-seeing-psionic', 'See all things as they really are.'),
new Array('Truevenom', 'Psychometabolism', '', '', 'Psychic Warrior 4', 'Material', 'psionicPowersQtoW.html#truevenom', 'Your natural weapons are covered in horrible poison.'),
new Array('Truevenom Weapon', 'Psychometabolism', 'Creation', '', 'Psychic Warrior 4', 'Material', 'psionicPowersQtoW.html#truevenom-weapon', 'Your weapon is horribly poisonous.'),
new Array('Ubiquitous Vision', 'Clairsentience', '', '', 'Psion/Wilder 3, Psychic Warrior 3', 'Visual', 'psionicPowersQtoW.html#ubiquitous-vision', 'You have all-around vision.'),
new Array('Ultrablast', 'Telepathy', '', 'Mind-Affecting', 'Psion/Wilder 7', 'Auditory', 'psionicPowersQtoW.html#ultrablast', 'Deal 13d6 damage in 15-ft. radius.'),
new Array('Vampiric Blade', 'Psychometabolism', '', '', 'Psychic Warrior 3', 'Material, Visual', 'psionicPowersQtoW.html#vampiric-blade', 'You heal half of your base weapon damage.'),
new Array('Vigor', 'Psychometabolism', '', '', 'Psion/Wilder 1, Psychic Warrior 1', 'Material, Olfactory', 'psionicPowersQtoW.html#vigor', 'Gain 5 temporary hit points.'),
new Array('Wall of Ectoplasm', 'Metacreativity', 'Creation', '', 'Psion/Wilder 4', 'Visual', 'psionicPowersQtoW.html#wall-of-ectoplasm', 'You create a protective barrier.'),
new Array('Wall Walker', 'Psychoportation', '', '', 'Psychic Warrior 2', 'Material', 'psionicPowersQtoW.html#wall-walker', 'Grants ability to walk on walls and ceilings.'),
new Array('Weapon of Energy', 'Psychokinesis', '', 'Cold, Electricity or Fire', 'Psychic Warrior 4', 'Visual', 'psionicPowersQtoW.html#weapon-of-energy', 'Weapon deals additional energy damage.')
);
